@@ -3,15 +3,13 @@
 #' Model Response Styles in Partial Credit Models
 #' 
 #' Performs PCMRS, a method to model response styles in Partial Credit Models
-#' 
-#' 
+"_PACKAGE"
 #' @name PCMRS-package
-#' @docType package
 #' @author Gunther Schauberger\cr \email{gunther.schauberger@@tum.de}\cr
 #' \url{https://www.sg.tum.de/epidemiologie/team/schauberger/}
 #' @seealso \code{\link{PCMRS}}, \code{\link{person.posterior}}, \code{\link{tenseness}}, \code{\link{emotion}}
 #' @references Tutz, Gerhard, Schauberger, Gunther and Berger, Moritz (2018): 
-#' Response Styles in the Partial Credit Model, \emph{Applied Psychological Measurement}, \url{https://journals.sagepub.com/doi/10.1177/0146621617748322}
+#' Response Styles in the Partial Credit Model, \emph{Applied Psychological Measurement}, \doi{10.1177/0146621617748322}
 #' @keywords package Partial Credit Response Style PCMRS
 #' @examples
 #' \dontshow{
@@ -77,7 +75,7 @@ NULL
 #' \item{Twitching mouth}{Do you notice unvoluntary twitching of your mouth?}
 #'  }
 #' @references Tutz, Gerhard, Schauberger, Gunther and Berger, Moritz (2018): 
-#' Response Styles in the Partial Credit Model, \emph{Applied Psychological Measurement}, \url{https://journals.sagepub.com/doi/10.1177/0146621617748322}
+#' Response Styles in the Partial Credit Model, \emph{Applied Psychological Measurement}, \doi{10.1177/0146621617748322}
 #' @source 
 #' ZPID (2013). PsychData of the Leibniz Institute for Psychology Information ZPID. Trier: Center for Research Data in Psychology.
 #' 
@@ -124,7 +122,7 @@ NULL
 #' \item{Trembling knees}{Do you start trembling in excitement or do you get trembling knees?}
 #'  }
 #' @references Tutz, Gerhard, Schauberger, Gunther and Berger, Moritz (2018): 
-#' Response Styles in the Partial Credit Model, \emph{Applied Psychological Measurement}, \url{https://journals.sagepub.com/doi/10.1177/0146621617748322}
+#' Response Styles in the Partial Credit Model, \emph{Applied Psychological Measurement}, \doi{10.1177/0146621617748322}
 #' @source 
 #' ZPID (2013). PsychData of the Leibniz Institute for Psychology Information ZPID. Trier: Center for Research Data in Psychology.
 #' 
